# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import log_pb2 as log__pb2
from . import tag_pb2 as tag__pb2
from . import common_pb2 as common__pb2
from . import filesystem_pb2 as filesystem__pb2
from . import image_pb2 as image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tjob.proto\x12\nbatchx.job\x1a\tlog.proto\x1a\ttag.proto\x1a\x0c\x63ommon.proto\x1a\x10\x66ilesystem.proto\x1a\x0bimage.proto\"x\n\x1bGetComputationalCostRequest\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamily\"\x92\x01\n\x1cGetComputationalCostResponse\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x17\n\x0f\x63ost_per_second\x18\x05 \x01(\x03\"\xf9\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12\x11\n\tts_submit\x18\x03 \x01(\x03\x12\x10\n\x08ts_start\x18\x04 \x01(\x03\x12\x11\n\tts_finish\x18\x05 \x01(\x03\x12\"\n\x06status\x18\x06 \x01(\x0e\x32\x12.batchx.job.Status\x12\r\n\x05vcpus\x18\x07 \x01(\x05\x12\x0e\n\x06memory\x18\x08 \x01(\x05\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\n\n\x02\x62y\x18\n \x01(\t\x12\x12\n\ninput_hash\x18\x0b \x01(\t\x12\x12\n\ninput_size\x18\x0c \x01(\x03\x12\x0c\n\x04gpus\x18\r \x01(\x05\x12\x11\n\texit_code\x18\x0e \x01(\x05\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12,\n\ngpu_family\x18\x10 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x15\n\rerror_message\x18\x11 \x01(\t\x12\x13\n\x0boutput_size\x18\x12 \x01(\x03\x12\x13\n\x0bworkflow_id\x18\x13 \x01(\x05\x12\x0e\n\x06\x63\x61\x63hed\x18\x14 \x01(\x08\x12\x1c\n\x03tag\x18\x15 \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x1b\n\x13original_input_json\x18\x16 \x01(\t\x12\x12\n\ninput_json\x18\x17 \x01(\t\x12\x13\n\x0boutput_json\x18\x18 \x01(\t\x12#\n\x1b\x63omputation_cost_per_second\x18\x19 \x01(\x03\x12\x12\n\nimage_cost\x18\x1a \x01(\x03\x12\x0f\n\x07runtime\x18\x1b \x01(\x03\x12\x12\n\ntotal_cost\x18\x1c \x01(\x03\x12\x11\n\tlogs_size\x18\x1d \x01(\x03\x12\x1d\n\x15workflow_orchestrator\x18\x1e \x01(\x08\x12\x38\n\rimage_pricing\x18\x1f \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x12\x1b\n\x13\x62illing_input_lines\x18  \x01(\x03\x12\x1b\n\x13\x62illing_input_bytes\x18! \x01(\x03\"\xbb\x03\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\x12\x10\n\x08ts_start\x18\x03 \x01(\x03\x12\x11\n\tts_finish\x18\x04 \x01(\x03\x12\x33\n\x06status\x18\x05 \x01(\x0e\x32#.batchx.job.Workflow.WorkflowStatus\x12\x12\n\njobs_count\x18\x06 \x01(\x05\x12\x13\n\x0btotal_price\x18\x07 \x01(\x03\x12\n\n\x02\x62y\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\t \x01(\x08\x12\x1c\n\x03tag\x18\n \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x18\n\x10ts_last_activity\x18\x0b \x01(\x03\x12\x19\n\x11\x61\x63tive_jobs_count\x18\x0c \x01(\x05\x12\x15\n\rerror_message\x18\r \x01(\t\x12\x11\n\tparent_id\x18\x0e \x01(\x05\x12\x17\n\x0forchestrator_id\x18\x0f \x01(\x05\"^\n\x0eWorkflowStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04OPEN\x10\n\x12\n\n\x06\x43LOSED\x10\x32\x12\r\n\tSUCCEEDED\x10\x64\x12\r\n\x08INACTIVE\x10\xc8\x01\x12\x0b\n\x06\x46\x41ILED\x10\xac\x02\"O\n\x15\x43reateWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"\'\n\x16\x43reateWorkflowResponse\x12\r\n\x05token\x18\x01 \x01(\t\"W\n\x14\x43loseWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\tJ\x04\x08\x03\x10\x04\"\x17\n\x15\x43loseWorkflowResponse\"4\n\rGetJobRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"n\n\rTagJobRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12(\n\x04tags\x18\x03 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x04 \x01(\x08\"\x10\n\x0eTagJobResponse\"x\n\x12TagWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12(\n\x04tags\x18\x03 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x04 \x01(\x08\"\x15\n\x13TagWorkflowResponse\"b\n\x0eGetJobResponse\x12\x1c\n\x03job\x18\x01 \x01(\x0b\x32\x0f.batchx.job.Job\x12&\n\tuser_data\x18\x04 \x01(\x0b\x32\x13.batchx.common.UserJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\">\n\x12GetWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"k\n\x13GetWorkflowResponse\x12&\n\x08workflow\x18\x01 \x01(\x0b\x32\x14.batchx.job.Workflow\x12&\n\tuser_data\x18\x03 \x01(\x0b\x32\x13.batchx.common.UserJ\x04\x08\x02\x10\x03\"C\n\x17GetWorkflowGraphRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"\x89\x06\n\x18GetWorkflowGraphResponse\x12\x37\n\x04node\x18\x01 \x03(\x0b\x32).batchx.job.GetWorkflowGraphResponse.Node\x12\x37\n\x04\x65\x64ge\x18\x02 \x03(\x0b\x32).batchx.job.GetWorkflowGraphResponse.Edge\x1a\xe4\x03\n\nJobMetrics\x12\\\n\x0fstatus_counters\x18\x01 \x03(\x0b\x32\x43.batchx.job.GetWorkflowGraphResponse.JobMetrics.StatusCountersEntry\x12R\n\rimage_credits\x18\x02 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x12X\n\x13\x63omputation_credits\x18\x03 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x12L\n\x07runtime\x18\x04 \x01(\x0b\x32;.batchx.job.GetWorkflowGraphResponse.JobMetrics.LongMetrics\x1a\x35\n\x13StatusCountersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x45\n\x0bLongMetrics\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x03\x12\x0b\n\x03sum\x18\x04 \x01(\x03\x1al\n\x04Node\x12\r\n\x05image\x18\x01 \x01(\t\x12\x10\n\x08pipeline\x18\x02 \x01(\x08\x12\x43\n\njobMetrics\x18\x03 \x01(\x0b\x32/.batchx.job.GetWorkflowGraphResponse.JobMetrics\x1a&\n\x04\x45\x64ge\x12\x0e\n\x06source\x18\x01 \x01(\x05\x12\x0e\n\x06target\x18\x02 \x01(\x05\"\xbc\x0b\n\x0fListJobsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x30\n\x05order\x18\x03 \x01(\x0b\x32!.batchx.job.ListJobsRequest.Order\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.batchx.job.ListJobsRequest.Pagination\x12\x38\n\tfiltering\x18\x05 \x01(\x0b\x32%.batchx.job.ListJobsRequest.Filtering\x1a\xf0\x01\n\x05Order\x12;\n\x08order_by\x18\x01 \x01(\x0e\x32).batchx.job.ListJobsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"\x85\x01\n\x07OrderBy\x12\x06\n\x02ID\x10\x00\x12\r\n\tTS_FINISH\x10\x01\x12\x14\n\x10\x43OMPUTATION_COST\x10\x02\x12\x0e\n\nIMAGE_COST\x10\x03\x12\x0b\n\x07RUNTIME\x10\x04\x12\x0e\n\nINPUT_SIZE\x10\x05\x12\x0f\n\x0bOUTPUT_SIZE\x10\x06\x12\x0f\n\x0bWORKFLOW_ID\x10\x07\x1a\x8e\x02\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12?\n\x07memento\x18\x02 \x01(\x0b\x32..batchx.job.ListJobsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1a\x90\x01\n\x07Memento\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tts_finish\x18\x02 \x01(\x03\x12\x18\n\x10\x63omputation_cost\x18\x03 \x01(\x03\x12\x12\n\nimage_cost\x18\x04 \x01(\x03\x12\x0f\n\x07runtime\x18\x05 \x01(\x03\x12\x12\n\ninput_size\x18\x06 \x01(\x03\x12\x13\n\x0boutput_size\x18\x07 \x01(\x03\x1a\xe1\x05\n\tFiltering\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12@\n\x05image\x18\x02 \x03(\x0b\x32\x31.batchx.job.ListJobsRequest.Filtering.ImageFilter\x12\x31\n\tsubmitted\x18\x03 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x32\n\ninput_size\x18\x05 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x33\n\x0boutput_size\x18\x06 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\"\n\x06status\x18\x07 \x03(\x0e\x32\x12.batchx.job.Status\x12/\n\x07runtime\x18\x08 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\nimage_cost\x18\t \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x38\n\x10\x63omputation_cost\x18\n \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\ntotal_cost\x18\x0b \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\'\n\x03tag\x18\x0c \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x32\n\x0bworkflow_id\x18\r \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12\x14\n\x0cshow_deleted\x18\x0e \x01(\x08\x1aS\n\x0bImageFilter\x12\x19\n\x11image_environment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x15\n\rimage_version\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"\xfa\x01\n\x10ListJobsResponse\x12\x1c\n\x03job\x18\x01 \x03(\x0b\x32\x0f.batchx.job.Job\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12=\n\tuser_data\x18\x04 \x03(\x0b\x32*.batchx.job.ListJobsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01J\x04\x08\x03\x10\x04\"\x84\x08\n\x14ListWorkflowsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x35\n\x05order\x18\x03 \x01(\x0b\x32&.batchx.job.ListWorkflowsRequest.Order\x12?\n\npagination\x18\x04 \x01(\x0b\x32+.batchx.job.ListWorkflowsRequest.Pagination\x12=\n\tfiltering\x18\x05 \x01(\x0b\x32*.batchx.job.ListWorkflowsRequest.Filtering\x1a\xb0\x01\n\x05Order\x12@\n\x08order_by\x18\x01 \x01(\x0e\x32..batchx.job.ListWorkflowsRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"A\n\x07OrderBy\x12\x06\n\x02ID\x10\x00\x12\r\n\tTS_FINISH\x10\x01\x12\x08\n\x04JOBS\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\x08\n\x04\x43OST\x10\x04\x1a\xd7\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x44\n\x07memento\x18\x02 \x01(\x0b\x32\x33.batchx.job.ListWorkflowsRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1aU\n\x07Memento\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tts_finish\x18\x02 \x01(\x03\x12\x0c\n\x04jobs\x18\x03 \x01(\x05\x12\x0f\n\x07runtime\x18\x04 \x01(\x03\x12\x0c\n\x04\x63ost\x18\x05 \x01(\x03\x1a\x8c\x03\n\tFiltering\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12\r\n\x05label\x18\x02 \x01(\t\x12\x31\n\tsubmitted\x18\x03 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x33\n\x06status\x18\x05 \x03(\x0e\x32#.batchx.job.Workflow.WorkflowStatus\x12+\n\x04jobs\x18\x06 \x01(\x0b\x32\x1d.batchx.common.IntRangeFilter\x12/\n\x07runtime\x18\x07 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x32\n\ntotal_cost\x18\x08 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\'\n\x03tag\x18\t \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x14\n\x0cshow_deleted\x18\n \x01(\x08J\x04\x08\x02\x10\x03\"\x8e\x02\n\x15ListWorkflowsResponse\x12&\n\x08workflow\x18\x01 \x03(\x0b\x32\x14.batchx.job.Workflow\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x42\n\tuser_data\x18\x04 \x03(\x0b\x32/.batchx.job.ListWorkflowsResponse.UserDataEntry\x12*\n\tpage_info\x18\x05 \x01(\x0b\x32\x17.batchx.common.PageInfo\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01J\x04\x08\x03\x10\x04\"\xa6\x02\n\rSubmitRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\r\n\x05vcpus\x18\x03 \x01(\x05\x12\x0e\n\x06memory\x18\x04 \x01(\x05\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x0c\n\x04gpus\x18\x06 \x01(\x05\x12\x14\n\x0cretry_job_id\x18\x07 \x01(\x05\x12\x10\n\x08no_cache\x18\x08 \x01(\x08\x12,\n\ngpu_family\x18\t \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x1d\n\x15no_suggest_parameters\x18\n \x01(\x08\x12\x16\n\x0eworkflow_token\x18\x0b \x01(\t\x12\x12\n\ninput_json\x18\x0c \x01(\t\x12\x12\n\nrequest_id\x18\r \x01(\t\"\xec\x01\n\x0eSubmitResponse\x12\x10\n\x06job_id\x18\x01 \x01(\x05H\x00\x12N\n\x14suggested_parameters\x18\x02 \x01(\x0b\x32..batchx.job.SubmitResponse.SuggestedParametersH\x00\x1ap\n\x13SuggestedParameters\x12\r\n\x05vcpus\x18\x01 \x01(\x05\x12\x0e\n\x06memory\x18\x02 \x01(\x05\x12\x0c\n\x04gpus\x18\x03 \x01(\x05\x12,\n\ngpu_family\x18\x04 \x01(\x0e\x32\x18.batchx.common.GpuFamilyB\x06\n\x04\x63\x61se\"J\n\rStreamRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\x14\n\x0clogs_enabled\x18\x03 \x01(\x08\"5\n\x0eStreamResponse\x12#\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x14.batchx.job.JobEvent\"V\n\x0eGetLogsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x10\n\x08\x62\x61\x63kward\x18\x04 \x01(\x08\"4\n\rCancelRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"\x10\n\x0e\x43\x61ncelResponse\"4\n\rDeleteRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\"\x10\n\x0e\x44\x65leteResponse\"A\n\x15\x44\x65leteWorkflowRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\"-\n\x16\x44\x65leteWorkflowResponse\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\x05\"\xfb\x03\n\x08JobEvent\x12+\n\nlog_record\x18\x01 \x01(\x0b\x32\x15.batchx.log.LogRecordH\x00\x12(\n\njob_status\x18\x02 \x01(\x0e\x32\x12.batchx.job.StatusH\x00\x12\x38\n\x0creturn_value\x18\x03 \x01(\x0b\x32 .batchx.job.JobEvent.ReturnValueH\x00\x12\x1f\n\x15\x63ompletion_percentage\x18\x04 \x01(\x05H\x00\x12\x0f\n\x07message\x18\x05 \x01(\t\x1a\xa3\x02\n\x0bReturnValue\x12\x11\n\texit_code\x18\x01 \x01(\x05\x12\x13\n\x0boutput_json\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x13\n\x0boutput_size\x18\x04 \x01(\x03\x12J\n\x0e\x66ile_meta_info\x18\x05 \x03(\x0b\x32\x32.batchx.job.JobEvent.ReturnValue.FileMetaInfoEntry\x12\x1d\n\x15\x63ontainer_output_json\x18\x06 \x01(\t\x1aU\n\x11\x46ileMetaInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .batchx.filesystem.Blob.MetaInfo:\x02\x38\x01\x42\x06\n\x04type\"g\n\x0fJobStateMessage\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12#\n\x05\x65vent\x18\x03 \x03(\x0b\x32\x14.batchx.job.JobEvent\x12\n\n\x02ts\x18\x04 \x01(\x03*\x98\x02\n\x06Status\x12\r\n\tSUBMITTED\x10\x00\x12\x0e\n\nPROCESSING\x10\x32\x12\n\n\x06QUEUED\x10\x64\x12\r\n\x08STARTING\x10\xc8\x01\x12\x16\n\x11\x44OWNLOADING_INPUT\x10\xac\x02\x12\x0c\n\x07RUNNING\x10\x90\x03\x12\x15\n\x10UPLOADING_OUTPUT\x10\xf4\x03\x12\x0f\n\nCANCELLING\x10\xd8\x04\x12\x0e\n\tSUCCEEDED\x10\xbc\x05\x12\x0c\n\x07WARNING\x10\xee\x05\x12\x0b\n\x06\x46\x41ILED\x10\xa0\x06\x12\x0e\n\tTIMED_OUT\x10\x84\x07\x12\x0e\n\tCANCELLED\x10\xe8\x07\x12\x12\n\rOUT_OF_MEMORY\x10\xcc\x08\x12\x13\n\x0eINVALID_OUTPUT\x10\xb0\t\x12\x12\n\rINVALID_INPUT\x10\x94\n2\xfd\n\n\nJobService\x12\x44\n\x06GetJob\x12\x19.batchx.job.GetJobRequest\x1a\x1a.batchx.job.GetJobResponse\"\x03\x90\x02\x01\x12n\n\x14GetComputationalCost\x12\'.batchx.job.GetComputationalCostRequest\x1a(.batchx.job.GetComputationalCostResponse\"\x03\x90\x02\x01\x12V\n\x08ListJobs\x12\x1b.batchx.job.ListJobsRequest\x1a\x1c.batchx.job.ListJobsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12\x44\n\x06Submit\x12\x19.batchx.job.SubmitRequest\x1a\x1a.batchx.job.SubmitResponse\"\x03\x90\x02\x02\x12\x46\n\x06Stream\x12\x19.batchx.job.StreamRequest\x1a\x1a.batchx.job.StreamResponse\"\x03\x90\x02\x02\x30\x01\x12O\n\x07GetLogs\x12\x1a.batchx.job.GetLogsRequest\x1a\x15.batchx.log.LogRecord\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x30\x01\x12P\n\x06\x44\x65lete\x12\x19.batchx.job.DeleteRequest\x1a\x1a.batchx.job.DeleteResponse\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x12h\n\x0e\x44\x65leteWorkflow\x12!.batchx.job.DeleteWorkflowRequest\x1a\".batchx.job.DeleteWorkflowResponse\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x01\x82\xa6\x1d\x02\x10\x01\x12\x44\n\x06\x43\x61ncel\x12\x19.batchx.job.CancelRequest\x1a\x1a.batchx.job.CancelResponse\"\x03\x90\x02\x02\x12\\\n\x0e\x43reateWorkflow\x12!.batchx.job.CreateWorkflowRequest\x1a\".batchx.job.CreateWorkflowResponse\"\x03\x90\x02\x02\x12Y\n\rCloseWorkflow\x12 .batchx.job.CloseWorkflowRequest\x1a!.batchx.job.CloseWorkflowResponse\"\x03\x90\x02\x02\x12\x65\n\rListWorkflows\x12 .batchx.job.ListWorkflowsRequest\x1a!.batchx.job.ListWorkflowsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12S\n\x0bGetWorkflow\x12\x1e.batchx.job.GetWorkflowRequest\x1a\x1f.batchx.job.GetWorkflowResponse\"\x03\x90\x02\x01\x12\x44\n\x06TagJob\x12\x19.batchx.job.TagJobRequest\x1a\x1a.batchx.job.TagJobResponse\"\x03\x90\x02\x02\x12S\n\x0bTagWorkflow\x12\x1e.batchx.job.TagWorkflowRequest\x1a\x1f.batchx.job.TagWorkflowResponse\"\x03\x90\x02\x02\x12\x62\n\x10GetWorkflowGraph\x12#.batchx.job.GetWorkflowGraphRequest\x1a$.batchx.job.GetWorkflowGraphResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1b\n\x0fio.batchx.protoB\x08JobProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\010JobProto'
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._options = None
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_options = b'8\001'
  _LISTJOBSRESPONSE_USERDATAENTRY._options = None
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._options = None
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._options = None
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_options = b'8\001'
  _JOBSERVICE._options = None
  _JOBSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _JOBSERVICE.methods_by_name['GetJob']._options = None
  _JOBSERVICE.methods_by_name['GetJob']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['GetComputationalCost']._options = None
  _JOBSERVICE.methods_by_name['GetComputationalCost']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['ListJobs']._options = None
  _JOBSERVICE.methods_by_name['ListJobs']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Submit']._options = None
  _JOBSERVICE.methods_by_name['Submit']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['Stream']._options = None
  _JOBSERVICE.methods_by_name['Stream']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['GetLogs']._options = None
  _JOBSERVICE.methods_by_name['GetLogs']._serialized_options = b'\220\002\001\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Delete']._options = None
  _JOBSERVICE.methods_by_name['Delete']._serialized_options = b'\220\002\002\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['DeleteWorkflow']._options = None
  _JOBSERVICE.methods_by_name['DeleteWorkflow']._serialized_options = b'\220\002\002\202\246\035\002\010\001\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['Cancel']._options = None
  _JOBSERVICE.methods_by_name['Cancel']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['CreateWorkflow']._options = None
  _JOBSERVICE.methods_by_name['CreateWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['CloseWorkflow']._options = None
  _JOBSERVICE.methods_by_name['CloseWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['ListWorkflows']._options = None
  _JOBSERVICE.methods_by_name['ListWorkflows']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _JOBSERVICE.methods_by_name['GetWorkflow']._options = None
  _JOBSERVICE.methods_by_name['GetWorkflow']._serialized_options = b'\220\002\001'
  _JOBSERVICE.methods_by_name['TagJob']._options = None
  _JOBSERVICE.methods_by_name['TagJob']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['TagWorkflow']._options = None
  _JOBSERVICE.methods_by_name['TagWorkflow']._serialized_options = b'\220\002\002'
  _JOBSERVICE.methods_by_name['GetWorkflowGraph']._options = None
  _JOBSERVICE.methods_by_name['GetWorkflowGraph']._serialized_options = b'\220\002\002'
  _STATUS._serialized_start=7917
  _STATUS._serialized_end=8197
  _GETCOMPUTATIONALCOSTREQUEST._serialized_start=92
  _GETCOMPUTATIONALCOSTREQUEST._serialized_end=212
  _GETCOMPUTATIONALCOSTRESPONSE._serialized_start=215
  _GETCOMPUTATIONALCOSTRESPONSE._serialized_end=361
  _JOB._serialized_start=364
  _JOB._serialized_end=1125
  _WORKFLOW._serialized_start=1128
  _WORKFLOW._serialized_end=1571
  _WORKFLOW_WORKFLOWSTATUS._serialized_start=1477
  _WORKFLOW_WORKFLOWSTATUS._serialized_end=1571
  _CREATEWORKFLOWREQUEST._serialized_start=1573
  _CREATEWORKFLOWREQUEST._serialized_end=1652
  _CREATEWORKFLOWRESPONSE._serialized_start=1654
  _CREATEWORKFLOWRESPONSE._serialized_end=1693
  _CLOSEWORKFLOWREQUEST._serialized_start=1695
  _CLOSEWORKFLOWREQUEST._serialized_end=1782
  _CLOSEWORKFLOWRESPONSE._serialized_start=1784
  _CLOSEWORKFLOWRESPONSE._serialized_end=1807
  _GETJOBREQUEST._serialized_start=1809
  _GETJOBREQUEST._serialized_end=1861
  _TAGJOBREQUEST._serialized_start=1863
  _TAGJOBREQUEST._serialized_end=1973
  _TAGJOBRESPONSE._serialized_start=1975
  _TAGJOBRESPONSE._serialized_end=1991
  _TAGWORKFLOWREQUEST._serialized_start=1993
  _TAGWORKFLOWREQUEST._serialized_end=2113
  _TAGWORKFLOWRESPONSE._serialized_start=2115
  _TAGWORKFLOWRESPONSE._serialized_end=2136
  _GETJOBRESPONSE._serialized_start=2138
  _GETJOBRESPONSE._serialized_end=2236
  _GETWORKFLOWREQUEST._serialized_start=2238
  _GETWORKFLOWREQUEST._serialized_end=2300
  _GETWORKFLOWRESPONSE._serialized_start=2302
  _GETWORKFLOWRESPONSE._serialized_end=2409
  _GETWORKFLOWGRAPHREQUEST._serialized_start=2411
  _GETWORKFLOWGRAPHREQUEST._serialized_end=2478
  _GETWORKFLOWGRAPHRESPONSE._serialized_start=2481
  _GETWORKFLOWGRAPHRESPONSE._serialized_end=3258
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS._serialized_start=2624
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS._serialized_end=3108
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_start=2984
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_end=3037
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_LONGMETRICS._serialized_start=3039
  _GETWORKFLOWGRAPHRESPONSE_JOBMETRICS_LONGMETRICS._serialized_end=3108
  _GETWORKFLOWGRAPHRESPONSE_NODE._serialized_start=3110
  _GETWORKFLOWGRAPHRESPONSE_NODE._serialized_end=3218
  _GETWORKFLOWGRAPHRESPONSE_EDGE._serialized_start=3220
  _GETWORKFLOWGRAPHRESPONSE_EDGE._serialized_end=3258
  _LISTJOBSREQUEST._serialized_start=3261
  _LISTJOBSREQUEST._serialized_end=4729
  _LISTJOBSREQUEST_ORDER._serialized_start=3470
  _LISTJOBSREQUEST_ORDER._serialized_end=3710
  _LISTJOBSREQUEST_ORDER_ORDERBY._serialized_start=3577
  _LISTJOBSREQUEST_ORDER_ORDERBY._serialized_end=3710
  _LISTJOBSREQUEST_PAGINATION._serialized_start=3713
  _LISTJOBSREQUEST_PAGINATION._serialized_end=3983
  _LISTJOBSREQUEST_PAGINATION_MEMENTO._serialized_start=3839
  _LISTJOBSREQUEST_PAGINATION_MEMENTO._serialized_end=3983
  _LISTJOBSREQUEST_FILTERING._serialized_start=3986
  _LISTJOBSREQUEST_FILTERING._serialized_end=4723
  _LISTJOBSREQUEST_FILTERING_IMAGEFILTER._serialized_start=4640
  _LISTJOBSREQUEST_FILTERING_IMAGEFILTER._serialized_end=4723
  _LISTJOBSRESPONSE._serialized_start=4732
  _LISTJOBSRESPONSE._serialized_end=4982
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_start=4908
  _LISTJOBSRESPONSE_USERDATAENTRY._serialized_end=4976
  _LISTWORKFLOWSREQUEST._serialized_start=4985
  _LISTWORKFLOWSREQUEST._serialized_end=6013
  _LISTWORKFLOWSREQUEST_ORDER._serialized_start=5214
  _LISTWORKFLOWSREQUEST_ORDER._serialized_end=5390
  _LISTWORKFLOWSREQUEST_ORDER_ORDERBY._serialized_start=5325
  _LISTWORKFLOWSREQUEST_ORDER_ORDERBY._serialized_end=5390
  _LISTWORKFLOWSREQUEST_PAGINATION._serialized_start=5393
  _LISTWORKFLOWSREQUEST_PAGINATION._serialized_end=5608
  _LISTWORKFLOWSREQUEST_PAGINATION_MEMENTO._serialized_start=5523
  _LISTWORKFLOWSREQUEST_PAGINATION_MEMENTO._serialized_end=5608
  _LISTWORKFLOWSREQUEST_FILTERING._serialized_start=5611
  _LISTWORKFLOWSREQUEST_FILTERING._serialized_end=6007
  _LISTWORKFLOWSRESPONSE._serialized_start=6016
  _LISTWORKFLOWSRESPONSE._serialized_end=6286
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_start=4908
  _LISTWORKFLOWSRESPONSE_USERDATAENTRY._serialized_end=4976
  _SUBMITREQUEST._serialized_start=6289
  _SUBMITREQUEST._serialized_end=6583
  _SUBMITRESPONSE._serialized_start=6586
  _SUBMITRESPONSE._serialized_end=6822
  _SUBMITRESPONSE_SUGGESTEDPARAMETERS._serialized_start=6702
  _SUBMITRESPONSE_SUGGESTEDPARAMETERS._serialized_end=6814
  _STREAMREQUEST._serialized_start=6824
  _STREAMREQUEST._serialized_end=6898
  _STREAMRESPONSE._serialized_start=6900
  _STREAMRESPONSE._serialized_end=6953
  _GETLOGSREQUEST._serialized_start=6955
  _GETLOGSREQUEST._serialized_end=7041
  _CANCELREQUEST._serialized_start=7043
  _CANCELREQUEST._serialized_end=7095
  _CANCELRESPONSE._serialized_start=7097
  _CANCELRESPONSE._serialized_end=7113
  _DELETEREQUEST._serialized_start=7115
  _DELETEREQUEST._serialized_end=7167
  _DELETERESPONSE._serialized_start=7169
  _DELETERESPONSE._serialized_end=7185
  _DELETEWORKFLOWREQUEST._serialized_start=7187
  _DELETEWORKFLOWREQUEST._serialized_end=7252
  _DELETEWORKFLOWRESPONSE._serialized_start=7254
  _DELETEWORKFLOWRESPONSE._serialized_end=7299
  _JOBEVENT._serialized_start=7302
  _JOBEVENT._serialized_end=7809
  _JOBEVENT_RETURNVALUE._serialized_start=7510
  _JOBEVENT_RETURNVALUE._serialized_end=7801
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_start=7716
  _JOBEVENT_RETURNVALUE_FILEMETAINFOENTRY._serialized_end=7801
  _JOBSTATEMESSAGE._serialized_start=7811
  _JOBSTATEMESSAGE._serialized_end=7914
  _JOBSERVICE._serialized_start=8200
  _JOBSERVICE._serialized_end=9605
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import alert_pb2 as alert__pb2


class AlertServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DismissAlert = channel.unary_unary(
                '/batchx.alert.AlertService/DismissAlert',
                request_serializer=alert__pb2.DismissAlertRequest.SerializeToString,
                response_deserializer=alert__pb2.DismissAlertResponse.FromString,
                )
        self.DismissAllAlerts = channel.unary_unary(
                '/batchx.alert.AlertService/DismissAllAlerts',
                request_serializer=alert__pb2.DismissAllAlertsRequest.SerializeToString,
                response_deserializer=alert__pb2.DismissAllAlertsResponse.FromString,
                )
        self.ListAlerts = channel.unary_unary(
                '/batchx.alert.AlertService/ListAlerts',
                request_serializer=alert__pb2.ListAlertsRequest.SerializeToString,
                response_deserializer=alert__pb2.ListAlertsResponse.FromString,
                )


class AlertServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DismissAlert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DismissAllAlerts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAlerts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DismissAlert': grpc.unary_unary_rpc_method_handler(
                    servicer.DismissAlert,
                    request_deserializer=alert__pb2.DismissAlertRequest.FromString,
                    response_serializer=alert__pb2.DismissAlertResponse.SerializeToString,
            ),
            'DismissAllAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.DismissAllAlerts,
                    request_deserializer=alert__pb2.DismissAllAlertsRequest.FromString,
                    response_serializer=alert__pb2.DismissAllAlertsResponse.SerializeToString,
            ),
            'ListAlerts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAlerts,
                    request_deserializer=alert__pb2.ListAlertsRequest.FromString,
                    response_serializer=alert__pb2.ListAlertsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.alert.AlertService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AlertService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DismissAlert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/DismissAlert',
            alert__pb2.DismissAlertRequest.SerializeToString,
            alert__pb2.DismissAlertResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DismissAllAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/DismissAllAlerts',
            alert__pb2.DismissAllAlertsRequest.SerializeToString,
            alert__pb2.DismissAllAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAlerts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.alert.AlertService/ListAlerts',
            alert__pb2.ListAlertsRequest.SerializeToString,
            alert__pb2.ListAlertsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import image_pb2 as image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rprofile.proto\x12\x0e\x62\x61tchx.profile\x1a\x0bimage.proto\"\x81\x02\n\x07Profile\x12\x10\n\x08markdown\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0btwitter_url\x18\x03 \x01(\t\x12\x14\n\x0clinkedin_url\x18\x04 \x01(\t\x12\x12\n\ngithub_url\x18\x05 \x01(\t\x12\x39\n\x0cpinned_image\x18\x06 \x03(\x0b\x32#.batchx.profile.Profile.PinnedImage\x1a]\n\x0bPinnedImage\x12\x13\n\tbase_name\x18\x01 \x01(\tH\x00\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x13.batchx.image.ImageH\x00\x42\x13\n\x11RequestOrResponseB\x1f\n\x0fio.batchx.protoB\x0cProfileProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'profile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\014ProfileProto'
  _PROFILE._serialized_start=47
  _PROFILE._serialized_end=304
  _PROFILE_PINNEDIMAGE._serialized_start=211
  _PROFILE_PINNEDIMAGE._serialized_end=304
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import picture_pb2 as picture__pb2


class PictureServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upload = channel.unary_unary(
                '/batchx.cdn.PictureService/Upload',
                request_serializer=picture__pb2.UploadRequest.SerializeToString,
                response_deserializer=picture__pb2.UploadResponse.FromString,
                )
        self.CompleteUpload = channel.unary_unary(
                '/batchx.cdn.PictureService/CompleteUpload',
                request_serializer=picture__pb2.CompleteUploadRequest.SerializeToString,
                response_deserializer=picture__pb2.CompleteUploadResponse.FromString,
                )
        self.CropPicture = channel.unary_unary(
                '/batchx.cdn.PictureService/CropPicture',
                request_serializer=picture__pb2.CropPictureRequest.SerializeToString,
                response_deserializer=picture__pb2.CropPictureResponse.FromString,
                )


class PictureServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Upload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CropPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PictureServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Upload': grpc.unary_unary_rpc_method_handler(
                    servicer.Upload,
                    request_deserializer=picture__pb2.UploadRequest.FromString,
                    response_serializer=picture__pb2.UploadResponse.SerializeToString,
            ),
            'CompleteUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteUpload,
                    request_deserializer=picture__pb2.CompleteUploadRequest.FromString,
                    response_serializer=picture__pb2.CompleteUploadResponse.SerializeToString,
            ),
            'CropPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.CropPicture,
                    request_deserializer=picture__pb2.CropPictureRequest.FromString,
                    response_serializer=picture__pb2.CropPictureResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.cdn.PictureService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PictureService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Upload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.cdn.PictureService/Upload',
            picture__pb2.UploadRequest.SerializeToString,
            picture__pb2.UploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.cdn.PictureService/CompleteUpload',
            picture__pb2.CompleteUploadRequest.SerializeToString,
            picture__pb2.CompleteUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CropPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.cdn.PictureService/CropPicture',
            picture__pb2.CropPictureRequest.SerializeToString,
            picture__pb2.CropPictureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from setuptools import setup

# Set package version
version = '0.0.0'
with open('version') as f:
    version = f.readline().strip()

try:
  import pypandoc
  long_description = pypandoc.convert_file('README.md', 'rst')
  print(long_description)
except(IOError, ImportError):
  long_description = open('README.md').read()

setup(name='batchx',
      version=version,
      description='Batchx Python API',
      long_description=long_description,
      author='Batchx',
      author_email='dev@batchx.com',
      url='https://github.com/batchx/api',
      packages=['batchx'],
      install_requires=[
          'grpcio', 'PyJWT', 'retry', 'google-api-python-client'
      ])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: docker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64ocker.proto\x12\rbatchx.docker\"[\n\x16\x44ockerImageCoordinates\x12\x10\n\x08registry\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x0e\n\x06\x64igest\x18\x04 \x01(\tB\x1e\n\x0fio.batchx.protoB\x0b\x44ockerProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'docker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\013DockerProto'
  _DOCKERIMAGECOORDINATES._serialized_start=31
  _DOCKERIMAGECOORDINATES._serialized_end=122
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\rbatchx.common\x1a google/protobuf/descriptor.proto\"\xa4\x01\n\tRateLimit\x12\x14\n\x0cmax_requests\x18\x01 \x01(\x05\x12\x38\n\x0btime_window\x18\x02 \x01(\x0e\x32#.batchx.common.RateLimit.TimeWindow\"G\n\nTimeWindow\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nPER_SECOND\x10\x01\x12\x0e\n\nPER_MINUTE\x10\x02\x12\x0c\n\x08PER_HOUR\x10\x03\"C\n\x07Picture\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\tthumbnail\x18\x02 \x03(\x0b\x32\x18.batchx.common.Thumbnail\"^\n\tThumbnail\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12%\n\x06source\x18\x04 \x01(\x0b\x32\x15.batchx.common.Region\"I\n\x06Region\x12\x0f\n\x07x_start\x18\x01 \x01(\x05\x12\x0f\n\x07y_start\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\"\xa2\x02\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x13\n\x0bts_creation\x18\x03 \x01(\x03\x12\x0e\n\x06public\x18\x04 \x01(\x08\x12\x12\n\nfirst_name\x18\x05 \x01(\t\x12\x11\n\tlast_name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x0f\n\x07\x63ompany\x18\x08 \x01(\t\x12\x10\n\x08location\x18\t \x01(\t\x12\x15\n\x0bpicture_key\x18\n \x01(\tH\x00\x12)\n\x07picture\x18\x0b \x01(\x0b\x32\x16.batchx.common.PictureH\x00\x12\x15\n\rbatchx_member\x18\x0c \x01(\x08\x12\x13\n\x0b\x64istributor\x18\r \x01(\tB\r\n\x0bpictureCase\"\xd6\x03\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bts_creation\x18\x02 \x01(\x03\x12\x0f\n\x07visible\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x15\n\x0bpicture_key\x18\x07 \x01(\tH\x00\x12)\n\x07picture\x18\x08 \x01(\x0b\x32\x16.batchx.common.PictureH\x00\x12\x19\n\x11\x66ounding_provider\x18\t \x01(\x08\x1a\xf2\x01\n\nMembership\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\x12\x0f\n\x07visible\x18\x02 \x01(\x08\x12!\n\x04user\x18\x03 \x01(\x0b\x32\x13.batchx.common.User\x12\x13\n\x0bts_creation\x18\x04 \x01(\x03\"V\n\x0eMembershipType\x12\x0b\n\x07REGULAR\x10\x00\x12\t\n\x05OWNER\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\n\n\x06VIEWER\x10\x03\x12\x0b\n\x07SUPPORT\x10\x04\x12\x08\n\x04NONE\x10\x05\x42\r\n\x0bpictureCase\"*\n\x0eIntRangeFilter\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02to\x18\x02 \x01(\x05\"+\n\x0fLongRangeFilter\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\"?\n\x08PageInfo\x12\x16\n\x0etotal_elements\x18\x01 \x01(\x05\x12\x1b\n\x13\x66irst_element_index\x18\x02 \x01(\x05*<\n\tGpuFamily\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04V100\x10\x01\x12\x07\n\x03K80\x10\x02\x12\x06\n\x02T4\x10\x03\x12\x07\n\x03M60\x10\x04:U\n\x11method_rate_limit\x12\x1e.google.protobuf.MethodOptions\x18\xe0\xd4\x03 \x01(\x0b\x32\x18.batchx.common.RateLimit:B\n\x18method_concurrence_limit\x12\x1e.google.protobuf.MethodOptions\x18\xe1\xd4\x03 \x01(\x05:W\n\x12service_rate_limit\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\xa2\x04 \x01(\x0b\x32\x18.batchx.common.RateLimit:D\n\x19service_concurrence_limit\x12\x1f.google.protobuf.ServiceOptions\x18\xf1\xa2\x04 \x01(\x05\x42\x1e\n\x0fio.batchx.protoB\x0b\x43ommonProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_rate_limit)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_concurrence_limit)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_rate_limit)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_concurrence_limit)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\013CommonProto'
  _GPUFAMILY._serialized_start=1392
  _GPUFAMILY._serialized_end=1452
  _RATELIMIT._serialized_start=66
  _RATELIMIT._serialized_end=230
  _RATELIMIT_TIMEWINDOW._serialized_start=159
  _RATELIMIT_TIMEWINDOW._serialized_end=230
  _PICTURE._serialized_start=232
  _PICTURE._serialized_end=299
  _THUMBNAIL._serialized_start=301
  _THUMBNAIL._serialized_end=395
  _REGION._serialized_start=397
  _REGION._serialized_end=470
  _USER._serialized_start=473
  _USER._serialized_end=763
  _ORGANIZATION._serialized_start=766
  _ORGANIZATION._serialized_end=1236
  _ORGANIZATION_MEMBERSHIP._serialized_start=979
  _ORGANIZATION_MEMBERSHIP._serialized_end=1221
  _ORGANIZATION_MEMBERSHIP_MEMBERSHIPTYPE._serialized_start=1135
  _ORGANIZATION_MEMBERSHIP_MEMBERSHIPTYPE._serialized_end=1221
  _INTRANGEFILTER._serialized_start=1238
  _INTRANGEFILTER._serialized_end=1280
  _LONGRANGEFILTER._serialized_start=1282
  _LONGRANGEFILTER._serialized_end=1325
  _PAGEINFO._serialized_start=1327
  _PAGEINFO._serialized_end=1390
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import tag_pb2 as tag__pb2


class TagServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTag = channel.unary_unary(
                '/batchx.tag.TagService/GetTag',
                request_serializer=tag__pb2.GetTagRequest.SerializeToString,
                response_deserializer=tag__pb2.GetTagResponse.FromString,
                )
        self.ListEnvironmentTags = channel.unary_unary(
                '/batchx.tag.TagService/ListEnvironmentTags',
                request_serializer=tag__pb2.ListEnvironmentTagsRequest.SerializeToString,
                response_deserializer=tag__pb2.ListEnvironmentTagsResponse.FromString,
                )
        self.CreateTag = channel.unary_unary(
                '/batchx.tag.TagService/CreateTag',
                request_serializer=tag__pb2.CreateTagRequest.SerializeToString,
                response_deserializer=tag__pb2.CreateTagResponse.FromString,
                )
        self.DisableTag = channel.unary_unary(
                '/batchx.tag.TagService/DisableTag',
                request_serializer=tag__pb2.DisableTagRequest.SerializeToString,
                response_deserializer=tag__pb2.DisableTagResponse.FromString,
                )
        self.DeleteTag = channel.unary_unary(
                '/batchx.tag.TagService/DeleteTag',
                request_serializer=tag__pb2.DeleteTagRequest.SerializeToString,
                response_deserializer=tag__pb2.DeleteTagResponse.FromString,
                )
        self.UpdateTag = channel.unary_unary(
                '/batchx.tag.TagService/UpdateTag',
                request_serializer=tag__pb2.UpdateTagRequest.SerializeToString,
                response_deserializer=tag__pb2.UpdateTagResponse.FromString,
                )


class TagServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironmentTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TagServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTag': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTag,
                    request_deserializer=tag__pb2.GetTagRequest.FromString,
                    response_serializer=tag__pb2.GetTagResponse.SerializeToString,
            ),
            'ListEnvironmentTags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironmentTags,
                    request_deserializer=tag__pb2.ListEnvironmentTagsRequest.FromString,
                    response_serializer=tag__pb2.ListEnvironmentTagsResponse.SerializeToString,
            ),
            'CreateTag': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTag,
                    request_deserializer=tag__pb2.CreateTagRequest.FromString,
                    response_serializer=tag__pb2.CreateTagResponse.SerializeToString,
            ),
            'DisableTag': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableTag,
                    request_deserializer=tag__pb2.DisableTagRequest.FromString,
                    response_serializer=tag__pb2.DisableTagResponse.SerializeToString,
            ),
            'DeleteTag': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTag,
                    request_deserializer=tag__pb2.DeleteTagRequest.FromString,
                    response_serializer=tag__pb2.DeleteTagResponse.SerializeToString,
            ),
            'UpdateTag': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTag,
                    request_deserializer=tag__pb2.UpdateTagRequest.FromString,
                    response_serializer=tag__pb2.UpdateTagResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'batchx.tag.TagService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TagService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/GetTag',
            tag__pb2.GetTagRequest.SerializeToString,
            tag__pb2.GetTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironmentTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/ListEnvironmentTags',
            tag__pb2.ListEnvironmentTagsRequest.SerializeToString,
            tag__pb2.ListEnvironmentTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/CreateTag',
            tag__pb2.CreateTagRequest.SerializeToString,
            tag__pb2.CreateTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/DisableTag',
            tag__pb2.DisableTagRequest.SerializeToString,
            tag__pb2.DisableTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/DeleteTag',
            tag__pb2.DeleteTagRequest.SerializeToString,
            tag__pb2.DeleteTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/batchx.tag.TagService/UpdateTag',
            tag__pb2.UpdateTagRequest.SerializeToString,
            tag__pb2.UpdateTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: organization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import profile_pb2 as profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12organization.proto\x12\x13\x62\x61tchx.organization\x1a\x0c\x63ommon.proto\x1a\rprofile.proto\"\x96\x01\n\nInvitation\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\n\n\x02\x62y\x18\x03 \x01(\t\x12\x43\n\x04type\x18\x04 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\x12\x12\n\ntsCreation\x18\x05 \x01(\x03\"=\n\x17\x44\x65leteMembershipRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteMembershipResponse\">\n\x17\x44\x65leteInvitationRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteInvitationResponse\"=\n\"ListOrganizationInvitationsRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"Z\n#ListOrganizationInvitationsResponse\x12\x33\n\ninvitation\x18\x01 \x03(\x0b\x32\x1f.batchx.organization.Invitation\"\x1c\n\x1aListUserInvitationsRequest\"R\n\x1bListUserInvitationsResponse\x12\x33\n\ninvitation\x18\x01 \x03(\x0b\x32\x1f.batchx.organization.Invitation\"B\n\x17HandleInvitationRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"\x1a\n\x18HandleInvitationResponse\"~\n\x13InviteMemberRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32\x35.batchx.common.Organization.Membership.MembershipType\"\x16\n\x14InviteMemberResponse\"\x9e\x01\n\x19\x43reateOrganizationRequest\x12-\n\x08org_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12\x1a\n\x12\x65nvironment_region\x18\x02 \x01(\t\x12\x19\n\x11\x63omputing_credits\x18\x03 \x01(\x03\x12\x1b\n\x13\x63redits_environment\x18\x04 \x01(\t\"\x1c\n\x1a\x43reateOrganizationResponse\"G\n\x16GetOrganizationRequest\x12\x14\n\x0corganization\x18\x01 \x01(\t\x12\x17\n\x0finclude_profile\x18\x02 \x01(\x08\"\xb7\x01\n\x17GetOrganizationResponse\x12\x36\n\x11organization_data\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12:\n\nmembership\x18\x02 \x03(\x0b\x32&.batchx.common.Organization.Membership\x12(\n\x07profile\x18\x03 \x01(\x0b\x32\x17.batchx.profile.Profile\"x\n\x19UpdateOrganizationRequest\x12\x31\n\x0corganization\x18\x01 \x01(\x0b\x32\x1b.batchx.common.Organization\x12(\n\x07profile\x18\x02 \x01(\x0b\x32\x17.batchx.profile.Profile\"\x1c\n\x1aUpdateOrganizationResponse2\xf1\x08\n\x13OrganizationService\x12q\n\x0fGetOrganization\x12+.batchx.organization.GetOrganizationRequest\x1a,.batchx.organization.GetOrganizationResponse\"\x03\x90\x02\x01\x12z\n\x12UpdateOrganization\x12..batchx.organization.UpdateOrganizationRequest\x1a/.batchx.organization.UpdateOrganizationResponse\"\x03\x90\x02\x02\x12z\n\x12\x43reateOrganization\x12..batchx.organization.CreateOrganizationRequest\x1a/.batchx.organization.CreateOrganizationResponse\"\x03\x90\x02\x02\x12h\n\x0cInviteMember\x12(.batchx.organization.InviteMemberRequest\x1a).batchx.organization.InviteMemberResponse\"\x03\x90\x02\x02\x12t\n\x10HandleInvitation\x12,.batchx.organization.HandleInvitationRequest\x1a-.batchx.organization.HandleInvitationResponse\"\x03\x90\x02\x02\x12\x95\x01\n\x1bListOrganizationInvitations\x12\x37.batchx.organization.ListOrganizationInvitationsRequest\x1a\x38.batchx.organization.ListOrganizationInvitationsResponse\"\x03\x90\x02\x02\x12}\n\x13ListUserInvitations\x12/.batchx.organization.ListUserInvitationsRequest\x1a\x30.batchx.organization.ListUserInvitationsResponse\"\x03\x90\x02\x02\x12t\n\x10\x44\x65leteInvitation\x12,.batchx.organization.DeleteInvitationRequest\x1a-.batchx.organization.DeleteInvitationResponse\"\x03\x90\x02\x02\x12t\n\x10\x44\x65leteMembership\x12,.batchx.organization.DeleteMembershipRequest\x1a-.batchx.organization.DeleteMembershipResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\x05\x82\x97\"\x02\x10\x01\x42\x11\n\x0fio.batchx.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'organization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.proto'
  _ORGANIZATIONSERVICE._options = None
  _ORGANIZATIONSERVICE._serialized_options = b'\202\227\"\002\010\005\202\227\"\002\020\001'
  _ORGANIZATIONSERVICE.methods_by_name['GetOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\220\002\001'
  _ORGANIZATIONSERVICE.methods_by_name['UpdateOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['CreateOrganization']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['InviteMember']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['InviteMember']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['HandleInvitation']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['HandleInvitation']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['ListOrganizationInvitations']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListOrganizationInvitations']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['ListUserInvitations']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListUserInvitations']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['DeleteInvitation']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['DeleteInvitation']._serialized_options = b'\220\002\002'
  _ORGANIZATIONSERVICE.methods_by_name['DeleteMembership']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['DeleteMembership']._serialized_options = b'\220\002\002'
  _INVITATION._serialized_start=73
  _INVITATION._serialized_end=223
  _DELETEMEMBERSHIPREQUEST._serialized_start=225
  _DELETEMEMBERSHIPREQUEST._serialized_end=286
  _DELETEMEMBERSHIPRESPONSE._serialized_start=288
  _DELETEMEMBERSHIPRESPONSE._serialized_end=314
  _DELETEINVITATIONREQUEST._serialized_start=316
  _DELETEINVITATIONREQUEST._serialized_end=378
  _DELETEINVITATIONRESPONSE._serialized_start=380
  _DELETEINVITATIONRESPONSE._serialized_end=406
  _LISTORGANIZATIONINVITATIONSREQUEST._serialized_start=408
  _LISTORGANIZATIONINVITATIONSREQUEST._serialized_end=469
  _LISTORGANIZATIONINVITATIONSRESPONSE._serialized_start=471
  _LISTORGANIZATIONINVITATIONSRESPONSE._serialized_end=561
  _LISTUSERINVITATIONSREQUEST._serialized_start=563
  _LISTUSERINVITATIONSREQUEST._serialized_end=591
  _LISTUSERINVITATIONSRESPONSE._serialized_start=593
  _LISTUSERINVITATIONSRESPONSE._serialized_end=675
  _HANDLEINVITATIONREQUEST._serialized_start=677
  _HANDLEINVITATIONREQUEST._serialized_end=743
  _HANDLEINVITATIONRESPONSE._serialized_start=745
  _HANDLEINVITATIONRESPONSE._serialized_end=771
  _INVITEMEMBERREQUEST._serialized_start=773
  _INVITEMEMBERREQUEST._serialized_end=899
  _INVITEMEMBERRESPONSE._serialized_start=901
  _INVITEMEMBERRESPONSE._serialized_end=923
  _CREATEORGANIZATIONREQUEST._serialized_start=926
  _CREATEORGANIZATIONREQUEST._serialized_end=1084
  _CREATEORGANIZATIONRESPONSE._serialized_start=1086
  _CREATEORGANIZATIONRESPONSE._serialized_end=1114
  _GETORGANIZATIONREQUEST._serialized_start=1116
  _GETORGANIZATIONREQUEST._serialized_end=1187
  _GETORGANIZATIONRESPONSE._serialized_start=1190
  _GETORGANIZATIONRESPONSE._serialized_end=1373
  _UPDATEORGANIZATIONREQUEST._serialized_start=1375
  _UPDATEORGANIZATIONREQUEST._serialized_end=1495
  _UPDATEORGANIZATIONRESPONSE._serialized_start=1497
  _UPDATEORGANIZATIONRESPONSE._serialized_end=1525
  _ORGANIZATIONSERVICE._serialized_start=1528
  _ORGANIZATIONSERVICE._serialized_end=2665
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import log_pb2 as log__pb2
from . import tag_pb2 as tag__pb2
from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bimage.proto\x12\x0c\x62\x61tchx.image\x1a\tlog.proto\x1a\ttag.proto\x1a\x0c\x63ommon.proto\"C\n\x1d\x41reImageExamplesClonedRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\"0\n\x1e\x41reImageExamplesClonedResponse\x12\x0e\n\x06\x63loned\x18\x01 \x01(\x08\"\xa2\x01\n\x19\x43loneImageExamplesRequest\x12\x1a\n\x12target_environment\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12:\n\x04type\x18\x03 \x01(\x0e\x32,.batchx.image.CloneImageExamplesRequest.Type\"\x1e\n\x04Type\x12\t\n\x05\x43LONE\x10\x00\x12\x0b\n\x07UNCLONE\x10\x01\"\x1c\n\x1a\x43loneImageExamplesResponse\")\n\x18ListImageExamplesRequest\x12\r\n\x05image\x18\x01 \x01(\t\"\xb2\x02\n\x19ListImageExamplesResponse\x12@\n\x07\x65xample\x18\x01 \x03(\x0b\x32/.batchx.image.ListImageExamplesResponse.Example\x1a\xd2\x01\n\x07\x45xample\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nts_sharing\x18\x04 \x01(\x03\x12\r\n\x05vcpus\x18\x05 \x01(\x05\x12\x0e\n\x06memory\x18\x06 \x01(\x05\x12\x0c\n\x04gpus\x18\x07 \x01(\x05\x12,\n\ngpu_family\x18\x08 \x01(\x0e\x32\x18.batchx.common.GpuFamily\x12\x12\n\ninput_json\x18\t \x01(\t\x12\x12\n\ninput_size\x18\n \x01(\x03\"M\n\x19RemoveImageExampleRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x12\n\nts_sharing\x18\x03 \x01(\x03\"i\n\x16SetImageExampleRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\"\x1c\n\x1aRemoveImageExampleResponse\"\x19\n\x17SetImageExampleResponse\"a\n\x19GetPushCredentialsRequest\x12\x19\n\x11image_environment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x15\n\rimage_version\x18\x03 \x01(\t\"N\n\x1aGetPushCredentialsResponse\x12\x14\n\x0c\x64ocker_token\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_coordinates\x18\x02 \x01(\t\"E\n\x12ImportImageRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_coordinates\x18\x02 \x01(\t\"\xfa\x11\n\x13SearchImagesRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12;\n\x05query\x18\x02 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x12\x1c\n\x14include_old_versions\x18\x03 \x01(\x08\x12;\n\x08order_by\x18\x04 \x03(\x0b\x32).batchx.image.SearchImagesRequest.OrderBy\x12@\n\npagination\x18\x05 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Pagination\x12\x36\n\x05\x66\x61\x63\x65t\x18\x06 \x03(\x0b\x32\'.batchx.image.SearchImagesRequest.Facet\x12>\n\thighlight\x18\x07 \x03(\x0b\x32+.batchx.image.SearchImagesRequest.Highlight\x1aG\n\x03\x41nd\x12@\n\nexpression\x18\x01 \x03(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1a\x46\n\x02Or\x12@\n\nexpression\x18\x01 \x03(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1aG\n\x03Not\x12@\n\nexpression\x18\x01 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.Expression\x1a\xdc\x02\n\nStringTerm\x12\x41\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x32.batchx.image.SearchImagesRequest.StringTerm.Field\x12\x0e\n\x04term\x18\x02 \x01(\tH\x00\x12\x10\n\x06prefix\x18\x03 \x01(\tH\x00\x12\x10\n\x06phrase\x18\x04 \x01(\tH\x00\"\xce\x01\n\x05\x46ield\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07VERSION\x10\x03\x12\n\n\x06\x41UTHOR\x10\x04\x12\x0e\n\nCATEGORIES\x10\x05\x12\x08\n\x04TAGS\x10\x06\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x07\x12\x11\n\rDOCUMENTATION\x10\x08\x12\t\n\x05INPUT\x10\t\x12\n\n\x06OUTPUT\x10\n\x12\x08\n\x04TYPE\x10\x0b\x12\x10\n\x0cVERSION_RANK\x10\x0c\x12\x0e\n\nVISIBILITY\x10\r\x12\x07\n\x03SCM\x10\x0e\x42\x06\n\x04Type\x1a\xab\x01\n\x0bNumericTerm\x12\x42\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x33.batchx.image.SearchImagesRequest.NumericTerm.Field\x12-\n\x05range\x18\x02 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\")\n\x05\x46ield\x12\t\n\x05PRICE\x10\x00\x12\x08\n\x04SIZE\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x1a\xc0\x02\n\nExpression\x12\x34\n\x03\x61nd\x18\x01 \x01(\x0b\x32%.batchx.image.SearchImagesRequest.AndH\x00\x12\x32\n\x02or\x18\x02 \x01(\x0b\x32$.batchx.image.SearchImagesRequest.OrH\x00\x12\x34\n\x03not\x18\x03 \x01(\x0b\x32%.batchx.image.SearchImagesRequest.NotH\x00\x12\x43\n\x0bstring_term\x18\x04 \x01(\x0b\x32,.batchx.image.SearchImagesRequest.StringTermH\x00\x12\x45\n\x0cnumeric_term\x18\x05 \x01(\x0b\x32-.batchx.image.SearchImagesRequest.NumericTermH\x00\x42\x06\n\x04Type\x1a\x8c\x01\n\x07OrderBy\x12>\n\x05\x66ield\x18\x01 \x01(\x0e\x32/.batchx.image.SearchImagesRequest.OrderBy.Field\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\"3\n\x05\x46ield\x12\x08\n\x04NAME\x10\x00\x12\t\n\x05PRICE\x10\x01\x12\x08\n\x04SIZE\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x1a)\n\nPagination\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\r\n\x05start\x18\x02 \x01(\x05\x1a\xdf\x02\n\x05\x46\x61\x63\x65t\x12<\n\x05\x66ield\x18\x01 \x01(\x0e\x32-.batchx.image.SearchImagesRequest.Facet.Field\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12:\n\x04sort\x18\x03 \x01(\x0e\x32,.batchx.image.SearchImagesRequest.Facet.Sort\x12.\n\x06\x62ucket\x18\x04 \x03(\x0b\x32\x1e.batchx.common.LongRangeFilter\"\x7f\n\x05\x46ield\x12\x0f\n\x0b\x45NVIRONMENT\x10\x00\x12\n\n\x06\x41UTHOR\x10\x01\x12\x0e\n\nCATEGORIES\x10\x02\x12\x08\n\x04TAGS\x10\x03\x12\x08\n\x04TYPE\x10\x04\x12\x08\n\x04SIZE\x10\x05\x12\t\n\x05PRICE\x10\x06\x12\x10\n\x0cVERSION_RANK\x10\x07\x12\x0e\n\nVISIBILITY\x10\x08\"\x1d\n\x04Sort\x12\t\n\x05\x43OUNT\x10\x00\x12\n\n\x06\x42UCKET\x10\x01\x1a\xb5\x02\n\tHighlight\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.batchx.image.SearchImagesRequest.Highlight.Field\x12\x42\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.batchx.image.SearchImagesRequest.Highlight.Format\x12\x13\n\x0bmax_phrases\x18\x03 \x01(\x05\x12\x0f\n\x07pre_tag\x18\x04 \x01(\t\x12\x10\n\x08post_tag\x18\x05 \x01(\t\"L\n\x05\x46ield\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rDOCUMENTATION\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\x12\t\n\x05INPUT\x10\x03\x12\n\n\x06OUTPUT\x10\x04\"\x1c\n\x06\x46ormat\x12\x08\n\x04HTML\x10\x00\x12\x08\n\x04TEXT\x10\x01\"\xe1\x06\n\x14SearchImagesResponse\x12\"\n\x05image\x18\x01 \x03(\x0b\x32\x13.batchx.image.Image\x12\x0c\n\x04hits\x18\x02 \x01(\x03\x12\x43\n\tuser_data\x18\x03 \x03(\x0b\x32\x30.batchx.image.SearchImagesResponse.UserDataEntry\x12\x41\n\x08org_data\x18\x04 \x03(\x0b\x32/.batchx.image.SearchImagesResponse.OrgDataEntry\x12\x44\n\x0c\x66\x61\x63\x65t_result\x18\x05 \x03(\x0b\x32..batchx.image.SearchImagesResponse.FacetResult\x12\x45\n\thighlight\x18\x06 \x03(\x0b\x32\x32.batchx.image.SearchImagesResponse.HighlightResult\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\x1aK\n\x0cOrgDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.batchx.common.Organization:\x02\x38\x01\x1a\xb7\x01\n\x0b\x46\x61\x63\x65tResult\x12<\n\x05\x66ield\x18\x01 \x01(\x0e\x32-.batchx.image.SearchImagesRequest.Facet.Field\x12\x43\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\x34.batchx.image.SearchImagesResponse.FacetResult.Entry\x1a%\n\x05\x45ntry\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x1a\xb4\x01\n\x0fHighlightResult\x12G\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x38.batchx.image.SearchImagesResponse.HighlightResult.Entry\x1aX\n\x05\x45ntry\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.batchx.image.SearchImagesRequest.Highlight.Field\x12\r\n\x05value\x18\x02 \x01(\t\"\xfb\x07\n\x11ListImagesRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x18\n\x10user_environment\x18\x02 \x01(\t\x12<\n\tfiltering\x18\x03 \x01(\x0b\x32).batchx.image.ListImagesRequest.Filtering\x12>\n\npagination\x18\x04 \x01(\x0b\x32*.batchx.image.ListImagesRequest.Pagination\x12\x34\n\x05order\x18\x05 \x01(\x0b\x32%.batchx.image.ListImagesRequest.Order\x12\x18\n\x10only_coordinates\x18\x06 \x01(\x08\x12\x18\n\x10include_manifest\x18\x07 \x01(\x08\x1a\xd4\x02\n\tFiltering\x12\'\n\x03tag\x18\x02 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x19\n\x11image_environment\x18\x03 \x03(\t\x12\x0c\n\x04user\x18\x04 \x03(\t\x12\x42\n\x07\x65xclude\x18\x05 \x01(\x0e\x32\x31.batchx.image.ListImagesRequest.Filtering.Exclude\x12\x31\n\tts_import\x18\x07 \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12,\n\x04size\x18\t \x01(\x0b\x32\x1e.batchx.common.LongRangeFilter\x12\x15\n\ronly_featured\x18\n \x01(\x08\"-\n\x07\x45xclude\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOOLS\x10\x01\x12\r\n\tPIPELINES\x10\x02J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\t\x1a\xd4\x01\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x43\n\x07memento\x18\x02 \x01(\x0b\x32\x32.batchx.image.ListImagesRequest.Pagination.Memento\x12\x19\n\x11\x63ompute_page_info\x18\x03 \x01(\x08\x1aS\n\x07Memento\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tts_import\x18\x04 \x01(\x03\x12\x0c\n\x04size\x18\x05 \x01(\x03J\x04\x08\x03\x10\x04\x1a\xa0\x01\n\x05Order\x12?\n\x08order_by\x18\x01 \x01(\x0e\x32-.batchx.image.ListImagesRequest.Order.OrderBy\x12\x11\n\torder_asc\x18\x02 \x01(\x08\x12\x0f\n\x07reverse\x18\x03 \x01(\x08\"2\n\x07OrderBy\x12\r\n\tTS_IMPORT\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04SIZE\x10\x03\"\x04\x08\x02\x10\x02\"\x8e\x03\n\x12ListImagesResponse\x12\"\n\x05image\x18\x01 \x03(\x0b\x32\x13.batchx.image.Image\x12\x11\n\tlast_page\x18\x02 \x01(\x08\x12\x41\n\tuser_data\x18\x03 \x03(\x0b\x32..batchx.image.ListImagesResponse.UserDataEntry\x12*\n\tpage_info\x18\x04 \x01(\x0b\x32\x17.batchx.common.PageInfo\x12?\n\x08org_data\x18\x05 \x03(\x0b\x32-.batchx.image.ListImagesResponse.OrgDataEntry\x1a\x44\n\rUserDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.batchx.common.User:\x02\x38\x01\x1aK\n\x0cOrgDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.batchx.common.Organization:\x02\x38\x01\"Z\n\x0fTagImageRequest\x12\r\n\x05image\x18\x01 \x01(\t\x12(\n\x04tags\x18\x02 \x03(\x0b\x32\x1a.batchx.tag.TagCoordinates\x12\x0e\n\x06remove\x18\x03 \x01(\x08\"\x12\n\x10TagImageResponse\" \n\x0fGetImageRequest\x12\r\n\x05image\x18\x01 \x01(\t\"\xd6\x01\n\x11ShareImageRequest\x12\x17\n\x0fimage_base_name\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.batchx.image.ShareImageRequest.Type\x12\x1a\n\x12target_environment\x18\x03 \x01(\t\x12\x32\n\x07pricing\x18\x05 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\"\x1e\n\x04Type\x12\t\n\x05SHARE\x10\x00\x12\x0b\n\x07UNSHARE\x10\x01J\x04\x08\x04\x10\x05\"\x9c\x01\n\x11\x43loneImageRequest\x12\x17\n\x0fimage_base_name\x18\x01 \x01(\t\x12\x1a\n\x12target_environment\x18\x02 \x01(\t\x12\x32\n\x04type\x18\x03 \x01(\x0e\x32$.batchx.image.CloneImageRequest.Type\"\x1e\n\x04Type\x12\t\n\x05\x43LONE\x10\x00\x12\x0b\n\x07UNCLONE\x10\x01\"\x14\n\x12\x43loneImageResponse\"\x14\n\x12ShareImageResponse\"K\n\x10GetImageResponse\x12\"\n\x05image\x18\x01 \x01(\x0b\x32\x13.batchx.image.Image\x12\x13\n\x0bmember_view\x18\x02 \x01(\x08\"=\n\x12\x44\x65leteImageRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\"\xa3\n\n\x05Image\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x18\n\x10manifest_version\x18\x05 \x01(\t\x12\x10\n\x08manifest\x18\x06 \x01(\t\x12\x1d\n\x15platform_architecture\x18\x07 \x01(\t\x12\x13\n\x0bplatform_os\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x32\n\nvisibility\x18\n \x01(\x0e\x32\x1e.batchx.image.Image.Visibility\x12\x11\n\tts_import\x18\x0b \x01(\x03\x12\n\n\x02\x62y\x18\x0c \x01(\t\x12\x0b\n\x03scm\x18\r \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12\x1c\n\x03tag\x18\x0f \x03(\x0b\x32\x0f.batchx.tag.Tag\x12\x10\n\x08versions\x18\x11 \x03(\t\x12(\n\x05share\x18\x12 \x03(\x0b\x32\x19.batchx.image.Image.Share\x12\x1a\n\x12\x63loning_envs_count\x18\x13 \x01(\x05\x12(\n\x05\x63lone\x18\x14 \x03(\x0b\x32\x19.batchx.image.Image.Share\x12\'\n\x07picture\x18\x15 \x01(\x0b\x32\x16.batchx.common.Picture\x12\x1c\n\x14pipeline_steps_count\x18\x16 \x01(\x05\x12\x35\n\x0cimage_status\x18\x17 \x01(\x0e\x32\x1f.batchx.image.Image.ImageStatus\x12\x10\n\x08\x66\x65\x61tured\x18\x18 \x01(\x08\x12\x32\n\x07pricing\x18\x19 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x1a\xa8\x04\n\x05Share\x12\x13\n\x0b\x65nvironment\x18\x03 \x01(\t\x12\'\n\x07picture\x18\x05 \x01(\x0b\x32\x16.batchx.common.Picture\x12,\n\x04type\x18\x06 \x01(\x0e\x32\x1e.batchx.image.Image.Share.Type\x12\x32\n\x07pricing\x18\x07 \x01(\x0b\x32!.batchx.image.Image.Share.Pricing\x1a\xd4\x02\n\x07Pricing\x12\x15\n\x0b\x66ixed_price\x18\x01 \x01(\x03H\x00\x12L\n\x0fper_mline_price\x18\x04 \x01(\x0b\x32\x31.batchx.image.Image.Share.Pricing.PerMlinePricingH\x00\x12L\n\x0fper_mbyte_price\x18\x05 \x01(\x0b\x32\x31.batchx.image.Image.Share.Pricing.PerMbytePricingH\x00\x1a@\n\x0fPerMlinePricing\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x13\n\x0bmline_price\x18\x03 \x01(\x03\x1a@\n\x0fPerMbytePricing\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x13\n\x0bmbyte_price\x18\x03 \x01(\x03\x42\x06\n\x04\x43\x61seJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\"\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x10\n\x0cORGANIZATION\x10\x01J\x04\x08\x04\x10\x05\")\n\nVisibility\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04SOME\x10\x02\"3\n\x0bImageStatus\x12\x0c\n\x08IMPORTED\x10\x00\x12\n\n\x06SHARED\x10\x01\x12\n\n\x06\x43LONED\x10\x02J\x04\x08\x10\x10\x11*9\n\x0cVERSION_RANK\x12\t\n\x05STALE\x10\x00\x12\x0b\n\x07HIGHEST\x10\x01\x12\x11\n\rHIGHEST_MAJOR\x10\x02\x32\xfd\n\n\x0cImageService\x12N\n\x0bImportImage\x12 .batchx.image.ImportImageRequest\x1a\x15.batchx.log.LogRecord\"\x04\x88\xa6\x1d\x01\x30\x01\x12x\n\x12GetPushCredentials\x12\'.batchx.image.GetPushCredentialsRequest\x1a(.batchx.image.GetPushCredentialsResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12`\n\nListImages\x12\x1f.batchx.image.ListImagesRequest\x1a .batchx.image.ListImagesResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12\x66\n\x0cSearchImages\x12!.batchx.image.SearchImagesRequest\x1a\".batchx.image.SearchImagesResponse\"\x0f\x90\x02\x01\x82\xa6\x1d\x02\x08\x03\x82\xa6\x1d\x02\x10\x01\x12N\n\x08GetImage\x12\x1d.batchx.image.GetImageRequest\x1a\x1e.batchx.image.GetImageResponse\"\x03\x90\x02\x01\x12T\n\nShareImage\x12\x1f.batchx.image.ShareImageRequest\x1a .batchx.image.ShareImageResponse\"\x03\x90\x02\x02\x12T\n\nCloneImage\x12\x1f.batchx.image.CloneImageRequest\x1a .batchx.image.CloneImageResponse\"\x03\x90\x02\x02\x12Y\n\x0b\x44\x65leteImage\x12 .batchx.image.DeleteImageRequest\x1a\x15.batchx.log.LogRecord\"\x0f\x90\x02\x02\x82\xa6\x1d\x02\x08\x05\x82\xa6\x1d\x02\x10\x02\x30\x01\x12N\n\x08TagImage\x12\x1d.batchx.image.TagImageRequest\x1a\x1e.batchx.image.TagImageResponse\"\x03\x90\x02\x02\x12x\n\x16\x41reImageExamplesCloned\x12+.batchx.image.AreImageExamplesClonedRequest\x1a,.batchx.image.AreImageExamplesClonedResponse\"\x03\x90\x02\x02\x12l\n\x12\x43loneImageExamples\x12\'.batchx.image.CloneImageExamplesRequest\x1a(.batchx.image.CloneImageExamplesResponse\"\x03\x90\x02\x02\x12i\n\x11ListImageExamples\x12&.batchx.image.ListImageExamplesRequest\x1a\'.batchx.image.ListImageExamplesResponse\"\x03\x90\x02\x02\x12\x63\n\x0fSetImageExample\x12$.batchx.image.SetImageExampleRequest\x1a%.batchx.image.SetImageExampleResponse\"\x03\x90\x02\x02\x12l\n\x12RemoveImageExample\x12\'.batchx.image.RemoveImageExampleRequest\x1a(.batchx.image.RemoveImageExampleResponse\"\x03\x90\x02\x02\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42\x1d\n\x0fio.batchx.protoB\nImageProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'image_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\nImageProto'
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._options = None
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._options = None
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_options = b'8\001'
  _LISTIMAGESRESPONSE_USERDATAENTRY._options = None
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_options = b'8\001'
  _LISTIMAGESRESPONSE_ORGDATAENTRY._options = None
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_options = b'8\001'
  _IMAGESERVICE._options = None
  _IMAGESERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _IMAGESERVICE.methods_by_name['ImportImage']._options = None
  _IMAGESERVICE.methods_by_name['ImportImage']._serialized_options = b'\210\246\035\001'
  _IMAGESERVICE.methods_by_name['GetPushCredentials']._options = None
  _IMAGESERVICE.methods_by_name['GetPushCredentials']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['ListImages']._options = None
  _IMAGESERVICE.methods_by_name['ListImages']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['SearchImages']._options = None
  _IMAGESERVICE.methods_by_name['SearchImages']._serialized_options = b'\220\002\001\202\246\035\002\010\003\202\246\035\002\020\001'
  _IMAGESERVICE.methods_by_name['GetImage']._options = None
  _IMAGESERVICE.methods_by_name['GetImage']._serialized_options = b'\220\002\001'
  _IMAGESERVICE.methods_by_name['ShareImage']._options = None
  _IMAGESERVICE.methods_by_name['ShareImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['CloneImage']._options = None
  _IMAGESERVICE.methods_by_name['CloneImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['DeleteImage']._options = None
  _IMAGESERVICE.methods_by_name['DeleteImage']._serialized_options = b'\220\002\002\202\246\035\002\010\005\202\246\035\002\020\002'
  _IMAGESERVICE.methods_by_name['TagImage']._options = None
  _IMAGESERVICE.methods_by_name['TagImage']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['AreImageExamplesCloned']._options = None
  _IMAGESERVICE.methods_by_name['AreImageExamplesCloned']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['CloneImageExamples']._options = None
  _IMAGESERVICE.methods_by_name['CloneImageExamples']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['ListImageExamples']._options = None
  _IMAGESERVICE.methods_by_name['ListImageExamples']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['SetImageExample']._options = None
  _IMAGESERVICE.methods_by_name['SetImageExample']._serialized_options = b'\220\002\002'
  _IMAGESERVICE.methods_by_name['RemoveImageExample']._options = None
  _IMAGESERVICE.methods_by_name['RemoveImageExample']._serialized_options = b'\220\002\002'
  _VERSION_RANK._serialized_start=7840
  _VERSION_RANK._serialized_end=7897
  _AREIMAGEEXAMPLESCLONEDREQUEST._serialized_start=65
  _AREIMAGEEXAMPLESCLONEDREQUEST._serialized_end=132
  _AREIMAGEEXAMPLESCLONEDRESPONSE._serialized_start=134
  _AREIMAGEEXAMPLESCLONEDRESPONSE._serialized_end=182
  _CLONEIMAGEEXAMPLESREQUEST._serialized_start=185
  _CLONEIMAGEEXAMPLESREQUEST._serialized_end=347
  _CLONEIMAGEEXAMPLESREQUEST_TYPE._serialized_start=317
  _CLONEIMAGEEXAMPLESREQUEST_TYPE._serialized_end=347
  _CLONEIMAGEEXAMPLESRESPONSE._serialized_start=349
  _CLONEIMAGEEXAMPLESRESPONSE._serialized_end=377
  _LISTIMAGEEXAMPLESREQUEST._serialized_start=379
  _LISTIMAGEEXAMPLESREQUEST._serialized_end=420
  _LISTIMAGEEXAMPLESRESPONSE._serialized_start=423
  _LISTIMAGEEXAMPLESRESPONSE._serialized_end=729
  _LISTIMAGEEXAMPLESRESPONSE_EXAMPLE._serialized_start=519
  _LISTIMAGEEXAMPLESRESPONSE_EXAMPLE._serialized_end=729
  _REMOVEIMAGEEXAMPLEREQUEST._serialized_start=731
  _REMOVEIMAGEEXAMPLEREQUEST._serialized_end=808
  _SETIMAGEEXAMPLEREQUEST._serialized_start=810
  _SETIMAGEEXAMPLEREQUEST._serialized_end=915
  _REMOVEIMAGEEXAMPLERESPONSE._serialized_start=917
  _REMOVEIMAGEEXAMPLERESPONSE._serialized_end=945
  _SETIMAGEEXAMPLERESPONSE._serialized_start=947
  _SETIMAGEEXAMPLERESPONSE._serialized_end=972
  _GETPUSHCREDENTIALSREQUEST._serialized_start=974
  _GETPUSHCREDENTIALSREQUEST._serialized_end=1071
  _GETPUSHCREDENTIALSRESPONSE._serialized_start=1073
  _GETPUSHCREDENTIALSRESPONSE._serialized_end=1151
  _IMPORTIMAGEREQUEST._serialized_start=1153
  _IMPORTIMAGEREQUEST._serialized_end=1222
  _SEARCHIMAGESREQUEST._serialized_start=1225
  _SEARCHIMAGESREQUEST._serialized_end=3523
  _SEARCHIMAGESREQUEST_AND._serialized_start=1607
  _SEARCHIMAGESREQUEST_AND._serialized_end=1678
  _SEARCHIMAGESREQUEST_OR._serialized_start=1680
  _SEARCHIMAGESREQUEST_OR._serialized_end=1750
  _SEARCHIMAGESREQUEST_NOT._serialized_start=1752
  _SEARCHIMAGESREQUEST_NOT._serialized_end=1823
  _SEARCHIMAGESREQUEST_STRINGTERM._serialized_start=1826
  _SEARCHIMAGESREQUEST_STRINGTERM._serialized_end=2174
  _SEARCHIMAGESREQUEST_STRINGTERM_FIELD._serialized_start=1960
  _SEARCHIMAGESREQUEST_STRINGTERM_FIELD._serialized_end=2166
  _SEARCHIMAGESREQUEST_NUMERICTERM._serialized_start=2177
  _SEARCHIMAGESREQUEST_NUMERICTERM._serialized_end=2348
  _SEARCHIMAGESREQUEST_NUMERICTERM_FIELD._serialized_start=2307
  _SEARCHIMAGESREQUEST_NUMERICTERM_FIELD._serialized_end=2348
  _SEARCHIMAGESREQUEST_EXPRESSION._serialized_start=2351
  _SEARCHIMAGESREQUEST_EXPRESSION._serialized_end=2671
  _SEARCHIMAGESREQUEST_ORDERBY._serialized_start=2674
  _SEARCHIMAGESREQUEST_ORDERBY._serialized_end=2814
  _SEARCHIMAGESREQUEST_ORDERBY_FIELD._serialized_start=2763
  _SEARCHIMAGESREQUEST_ORDERBY_FIELD._serialized_end=2814
  _SEARCHIMAGESREQUEST_PAGINATION._serialized_start=2816
  _SEARCHIMAGESREQUEST_PAGINATION._serialized_end=2857
  _SEARCHIMAGESREQUEST_FACET._serialized_start=2860
  _SEARCHIMAGESREQUEST_FACET._serialized_end=3211
  _SEARCHIMAGESREQUEST_FACET_FIELD._serialized_start=3053
  _SEARCHIMAGESREQUEST_FACET_FIELD._serialized_end=3180
  _SEARCHIMAGESREQUEST_FACET_SORT._serialized_start=3182
  _SEARCHIMAGESREQUEST_FACET_SORT._serialized_end=3211
  _SEARCHIMAGESREQUEST_HIGHLIGHT._serialized_start=3214
  _SEARCHIMAGESREQUEST_HIGHLIGHT._serialized_end=3523
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FIELD._serialized_start=3417
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FIELD._serialized_end=3493
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FORMAT._serialized_start=3495
  _SEARCHIMAGESREQUEST_HIGHLIGHT_FORMAT._serialized_end=3523
  _SEARCHIMAGESRESPONSE._serialized_start=3526
  _SEARCHIMAGESRESPONSE._serialized_end=4391
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_start=3877
  _SEARCHIMAGESRESPONSE_USERDATAENTRY._serialized_end=3945
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_start=3947
  _SEARCHIMAGESRESPONSE_ORGDATAENTRY._serialized_end=4022
  _SEARCHIMAGESRESPONSE_FACETRESULT._serialized_start=4025
  _SEARCHIMAGESRESPONSE_FACETRESULT._serialized_end=4208
  _SEARCHIMAGESRESPONSE_FACETRESULT_ENTRY._serialized_start=4171
  _SEARCHIMAGESRESPONSE_FACETRESULT_ENTRY._serialized_end=4208
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT._serialized_start=4211
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT._serialized_end=4391
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT_ENTRY._serialized_start=4303
  _SEARCHIMAGESRESPONSE_HIGHLIGHTRESULT_ENTRY._serialized_end=4391
  _LISTIMAGESREQUEST._serialized_start=4394
  _LISTIMAGESREQUEST._serialized_end=5413
  _LISTIMAGESREQUEST_FILTERING._serialized_start=4695
  _LISTIMAGESREQUEST_FILTERING._serialized_end=5035
  _LISTIMAGESREQUEST_FILTERING_EXCLUDE._serialized_start=4978
  _LISTIMAGESREQUEST_FILTERING_EXCLUDE._serialized_end=5023
  _LISTIMAGESREQUEST_PAGINATION._serialized_start=5038
  _LISTIMAGESREQUEST_PAGINATION._serialized_end=5250
  _LISTIMAGESREQUEST_PAGINATION_MEMENTO._serialized_start=5167
  _LISTIMAGESREQUEST_PAGINATION_MEMENTO._serialized_end=5250
  _LISTIMAGESREQUEST_ORDER._serialized_start=5253
  _LISTIMAGESREQUEST_ORDER._serialized_end=5413
  _LISTIMAGESREQUEST_ORDER_ORDERBY._serialized_start=5363
  _LISTIMAGESREQUEST_ORDER_ORDERBY._serialized_end=5413
  _LISTIMAGESRESPONSE._serialized_start=5416
  _LISTIMAGESRESPONSE._serialized_end=5814
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_start=3877
  _LISTIMAGESRESPONSE_USERDATAENTRY._serialized_end=3945
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_start=3947
  _LISTIMAGESRESPONSE_ORGDATAENTRY._serialized_end=4022
  _TAGIMAGEREQUEST._serialized_start=5816
  _TAGIMAGEREQUEST._serialized_end=5906
  _TAGIMAGERESPONSE._serialized_start=5908
  _TAGIMAGERESPONSE._serialized_end=5926
  _GETIMAGEREQUEST._serialized_start=5928
  _GETIMAGEREQUEST._serialized_end=5960
  _SHAREIMAGEREQUEST._serialized_start=5963
  _SHAREIMAGEREQUEST._serialized_end=6177
  _SHAREIMAGEREQUEST_TYPE._serialized_start=6141
  _SHAREIMAGEREQUEST_TYPE._serialized_end=6171
  _CLONEIMAGEREQUEST._serialized_start=6180
  _CLONEIMAGEREQUEST._serialized_end=6336
  _CLONEIMAGEREQUEST_TYPE._serialized_start=317
  _CLONEIMAGEREQUEST_TYPE._serialized_end=347
  _CLONEIMAGERESPONSE._serialized_start=6338
  _CLONEIMAGERESPONSE._serialized_end=6358
  _SHAREIMAGERESPONSE._serialized_start=6360
  _SHAREIMAGERESPONSE._serialized_end=6380
  _GETIMAGERESPONSE._serialized_start=6382
  _GETIMAGERESPONSE._serialized_end=6457
  _DELETEIMAGEREQUEST._serialized_start=6459
  _DELETEIMAGEREQUEST._serialized_end=6520
  _IMAGE._serialized_start=6523
  _IMAGE._serialized_end=7838
  _IMAGE_SHARE._serialized_start=7184
  _IMAGE_SHARE._serialized_end=7736
  _IMAGE_SHARE_PRICING._serialized_start=7354
  _IMAGE_SHARE_PRICING._serialized_end=7694
  _IMAGE_SHARE_PRICING_PERMLINEPRICING._serialized_start=7544
  _IMAGE_SHARE_PRICING_PERMLINEPRICING._serialized_end=7608
  _IMAGE_SHARE_PRICING_PERMBYTEPRICING._serialized_start=7610
  _IMAGE_SHARE_PRICING_PERMBYTEPRICING._serialized_end=7674
  _IMAGE_SHARE_TYPE._serialized_start=7696
  _IMAGE_SHARE_TYPE._serialized_end=7730
  _IMAGE_VISIBILITY._serialized_start=7738
  _IMAGE_VISIBILITY._serialized_end=7779
  _IMAGE_IMAGESTATUS._serialized_start=7781
  _IMAGE_IMAGESTATUS._serialized_end=7832
  _IMAGESERVICE._serialized_start=7900
  _IMAGESERVICE._serialized_end=9305
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: log.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tlog.proto\x12\nbatchx.log\"\xb4\x01\n\tLogRecord\x12 \n\x05level\x18\x01 \x01(\x0e\x32\x11.batchx.log.Level\x12\x11\n\tts_millis\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\x12,\n\x06source\x18\x04 \x01(\x0e\x32\x1c.batchx.log.LogRecord.Source\"3\n\x06Source\x12\x12\n\x0eUNKNOWN_SOURCE\x10\x00\x12\x06\n\x02\x42X\x10\x01\x12\r\n\tCONTAINER\x10\x02*a\n\x05Level\x12\x15\n\x11UNKNOWN_LOG_LEVEL\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x08\n\x04INFO\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\t\n\x05QUIET\x10\x06\x42\x1b\n\x0fio.batchx.protoB\x08LogProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'log_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\010LogProto'
  _LEVEL._serialized_start=208
  _LEVEL._serialized_end=305
  _LOGRECORD._serialized_start=26
  _LOGRECORD._serialized_end=206
  _LOGRECORD_SOURCE._serialized_start=155
  _LOGRECORD_SOURCE._serialized_end=206
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: consumer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63onsumer.proto\x12\x0f\x62\x61tchx.consumer\x1a\x0c\x63ommon.proto\"Y\n\x11GetMetricsRequest\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\x0f\n\x07ts_from\x18\x02 \x01(\x03\x12\r\n\x05ts_to\x18\x03 \x01(\x03\x12\x0f\n\x07\x62uckets\x18\x04 \x01(\x05\"\xb2\x03\n\x12GetMetricsResponse\x12L\n\x0e\x62ucket_metrics\x18\x01 \x03(\x0b\x32\x34.batchx.consumer.GetMetricsResponse.JobBucketMetrics\x12\x43\n\x0bjob_metrics\x18\x02 \x01(\x0b\x32..batchx.consumer.GetMetricsResponse.JobMetrics\x1a\x66\n\x10JobBucketMetrics\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x05\x12\x12\n\nnon_cached\x18\x02 \x01(\x05\x12\x12\n\nimage_fees\x18\x03 \x01(\x03\x12\x19\n\x11\x63omputation_costs\x18\x04 \x01(\x03\x1a\xa0\x01\n\nJobMetrics\x12[\n\x0fstatus_counters\x18\x01 \x03(\x0b\x32\x42.batchx.consumer.GetMetricsResponse.JobMetrics.StatusCountersEntry\x1a\x35\n\x13StatusCountersEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x32{\n\x0f\x43onsumerService\x12Z\n\nGetMetrics\x12\".batchx.consumer.GetMetricsRequest\x1a#.batchx.consumer.GetMetricsResponse\"\x03\x90\x02\x01\x1a\x0c\x82\x97\"\x02\x08\n\x82\x97\"\x02\x10\x01\x42 \n\x0fio.batchx.protoB\rConsumerProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'consumer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017io.batchx.protoB\rConsumerProto'
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._options = None
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_options = b'8\001'
  _CONSUMERSERVICE._options = None
  _CONSUMERSERVICE._serialized_options = b'\202\227\"\002\010\n\202\227\"\002\020\001'
  _CONSUMERSERVICE.methods_by_name['GetMetrics']._options = None
  _CONSUMERSERVICE.methods_by_name['GetMetrics']._serialized_options = b'\220\002\001'
  _GETMETRICSREQUEST._serialized_start=49
  _GETMETRICSREQUEST._serialized_end=138
  _GETMETRICSRESPONSE._serialized_start=141
  _GETMETRICSRESPONSE._serialized_end=575
  _GETMETRICSRESPONSE_JOBBUCKETMETRICS._serialized_start=310
  _GETMETRICSRESPONSE_JOBBUCKETMETRICS._serialized_end=412
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_start=415
  _GETMETRICSRESPONSE_JOBMETRICS._serialized_end=575
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_start=522
  _GETMETRICSRESPONSE_JOBMETRICS_STATUSCOUNTERSENTRY._serialized_end=575
  _CONSUMERSERVICE._serialized_start=577
  _CONSUMERSERVICE._serialized_end=700
# @@protoc_insertion_point(module_scope)
